/**
 * @file lxAbout.h
 * Loch about dialog.
 */
  
/* Copyright (C) 2004 Stacho Mudrak
 * 
 * $Date: $
 * $RCSfile: $
 * $Revision: $
 */

#ifndef lxAboutDlg_h
#define lxAboutDlg_h


// Standard libraries
#ifndef LXDEPCHECK
#include <wx/window.h>
#endif  
//LXDEPCHECK - standard libraries

void lxShowAboutDialog(wxWindow * parent);




#endif

